package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.QuoteMaterialMapper;
import com.ruoyi.system.domain.QuoteMaterial;
import com.ruoyi.system.service.IQuoteMaterialService;

/**
 * 项目报价--物料信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@Service
public class QuoteMaterialServiceImpl implements IQuoteMaterialService 
{
    @Autowired
    private QuoteMaterialMapper quoteMaterialMapper;

    /**
     * 查询项目报价--物料信息
     * 
     * @param id 项目报价--物料信息主键
     * @return 项目报价--物料信息
     */
    @Override
    public QuoteMaterial selectQuoteMaterialById(Long id)
    {
        return quoteMaterialMapper.selectQuoteMaterialById(id);
    }


    /**
     * 查询项目报价--物料信息列表
     * 
     * @param quoteMaterial 项目报价--物料信息
     * @return 项目报价--物料信息
     */
    @Override
    public List<QuoteMaterial> selectQuoteMaterialList(QuoteMaterial quoteMaterial)
    {
        return quoteMaterialMapper.selectQuoteMaterialList(quoteMaterial);
    }

    /**
     * 新增项目报价--物料信息
     * 
     * @param quoteMaterial 项目报价--物料信息
     * @return 结果
     */
    @Override
    public int insertQuoteMaterial(QuoteMaterial quoteMaterial)
    {
        return quoteMaterialMapper.insertQuoteMaterial(quoteMaterial);
    }

    /**
     * 修改项目报价--物料信息
     * 
     * @param quoteMaterial 项目报价--物料信息
     * @return 结果
     */
    @Override
    public int updateQuoteMaterial(QuoteMaterial quoteMaterial)
    {
        return quoteMaterialMapper.updateQuoteMaterial(quoteMaterial);
    }

    /**
     * 批量删除项目报价--物料信息
     * 
     * @param ids 需要删除的项目报价--物料信息主键
     * @return 结果
     */
    @Override
    public int deleteQuoteMaterialByIds(Long[] ids)
    {
        return quoteMaterialMapper.deleteQuoteMaterialByIds(ids);
    }

    /**
     * 删除项目报价--物料信息信息
     * 
     * @param id 项目报价--物料信息主键
     * @return 结果
     */
    @Override
    public int deleteQuoteMaterialById(Long id)
    {
        return quoteMaterialMapper.deleteQuoteMaterialById(id);
    }
}
